==> tabular-data-resources-widget-1.0.0-20141210.105125-94.jar: org/gcube/portlets/user/td/resourceswidget/client/resources/ResourceBundle.java <==
package org.gcube.portlets.user.td.resourceswidget.client.resources;


import com.google.gwt.core.client.GWT;
import com.google.gwt.resources.client.ClientBundle;
import com.google.gwt.resources.client.ImageResource;

/**
 * 
 * @author "Giancarlo Panichi" 
 * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 *
 */
public interface ResourceBundle extends ClientBundle {
	
	public static final ResourceBundle INSTANCE=GWT.create(ResourceBundle.class);
	
	@Source("Dialog.css")
	DialogCSS dialogCSS();
	
	@Source("arrow-refresh_16.png")
	ImageResource refresh();
	
	@Source("arrow-refresh_24.png")
	ImageResource refresh24();
	
	
	@Source("arrow-refresh_32.png")
	ImageResource refresh32();
	
	@Source("magnifier.png")
	ImageResource magnifier();
	
	@Source("magnifier_32.png")
	ImageResource magnifier32();
	
	@Source("close-red.png")
	ImageResource close();
	
	@Source("close-red_32.png")
	ImageResource close32();
	
	@Source("disk.png")
	ImageResource save();
	
	@Source("disk_32.png")
	ImageResource save32();

	@Source("add.png")
	ImageResource add();
	
	@Source("add_32.png")
	ImageResource add32();
	
	@Source("delete.png")
	ImageResource delete();
	
	@Source("delete_32.png")
	ImageResource delete32();

	@Source("chart-bar.png")
	ImageResource chart();
	
	@Source("chart-bar_32.png")
	ImageResource chart32();
	
	@Source("codelist.png")
	ImageResource codelist();
	
	@Source("codelist_32.png")
	ImageResource codelist32();
	
	@Source("csv.png")
	ImageResource csv();
	
	@Source("csv_32.png")
	ImageResource csv32();
	
	@Source("gis.png")
	ImageResource gis();
	
	@Source("gis_32.png")
	ImageResource gis32();
	
	@Source("json.png")
	ImageResource json();
	
	@Source("json_32.png")
	ImageResource json32();
	
	@Source("sdmx.png")
	ImageResource sdmx();
	
	@Source("sdmx_32.png")
	ImageResource sdmx32();
	
	@Source("table.png")
	ImageResource table();
	
	@Source("table_32.png")
	ImageResource table32();
	
	@Source("resources.png")
	ImageResource resources();
	
	@Source("resources_32.png")
	ImageResource resources32();
	
	
	
}

==> tabular-data-resources-widget-1.0.0-20141211.133308-95.jar: org/gcube/portlets/user/td/resourceswidget/client/resources/ResourceBundle.java <==
package org.gcube.portlets.user.td.resourceswidget.client.resources;


import com.google.gwt.core.client.GWT;
import com.google.gwt.resources.client.ClientBundle;
import com.google.gwt.resources.client.ImageResource;

/**
 * 
 * @author "Giancarlo Panichi" 
 * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 *
 */
public interface ResourceBundle extends ClientBundle {
	
	public static final ResourceBundle INSTANCE=GWT.create(ResourceBundle.class);

	
	@Source("testImage.jpg")
	ImageResource testImage();
	
	
	@Source("arrow-refresh_16.png")
	ImageResource refresh();
	
	@Source("arrow-refresh_24.png")
	ImageResource refresh24();
	
	
	@Source("arrow-refresh_32.png")
	ImageResource refresh32();
	
	@Source("magnifier.png")
	ImageResource magnifier();
	
	@Source("magnifier_32.png")
	ImageResource magnifier32();
	
	@Source("close-red.png")
	ImageResource close();
	
	@Source("close-red_32.png")
	ImageResource close32();
	
	@Source("disk.png")
	ImageResource save();
	
	@Source("disk_32.png")
	ImageResource save32();

	@Source("add.png")
	ImageResource add();
	
	@Source("add_32.png")
	ImageResource add32();
	
	@Source("delete.png")
	ImageResource delete();
	
	@Source("delete_32.png")
	ImageResource delete32();

	@Source("chart-bar.png")
	ImageResource chart();
	
	@Source("chart-bar_32.png")
	ImageResource chart32();
	
	@Source("codelist.png")
	ImageResource codelist();
	
	@Source("codelist_32.png")
	ImageResource codelist32();
	
	@Source("csv.png")
	ImageResource csv();
	
	@Source("csv_32.png")
	ImageResource csv32();
	
	@Source("gis.png")
	ImageResource gis();
	
	@Source("gis_32.png")
	ImageResource gis32();
	
	@Source("json.png")
	ImageResource json();
	
	@Source("json_32.png")
	ImageResource json32();
	
	@Source("sdmx.png")
	ImageResource sdmx();
	
	@Source("sdmx_32.png")
	ImageResource sdmx32();
	
	@Source("table.png")
	ImageResource table();
	
	@Source("table_32.png")
	ImageResource table32();
	
	@Source("resources.png")
	ImageResource resources();
	
	@Source("resources_32.png")
	ImageResource resources32();
	
	@Source("magnifier-zoom-in_32.png")
	ImageResource magnifierZoomIn32();
	
	@Source("magnifier-zoom-in.png")
	ImageResource magnifierZoomIn();
	
	@Source("magnifier-zoom-out_32.png")
	ImageResource magnifierZoomOut32();
	
	@Source("magnifier-zoom-out.png")
	ImageResource magnifierZoomOut();
	
	@Source("arrow-move_32.png")
	ImageResource move32();
	
	@Source("arrow-move.png")
	ImageResource move();
	
	@Source("application_32.png")
	ImageResource application32();
	
	@Source("application.png")
	ImageResource application();
	
	@Source("Resources.css")
	ResourceCSS resourceCSS();
}
